/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "guideblock.h"
#include "guide.h"
#include "leakdetector.h"
#include "logger.h"

#include <QJsonArray>
#include <QJsonObject>

namespace {
Logger logger(LOG_MAIN, "GuideBlock");
}

GuideBlock::GuideBlock(QObject* parent) : QObject(parent) {
  MVPN_COUNT_CTOR(GuideBlock);
}

GuideBlock::~GuideBlock() { MVPN_COUNT_DTOR(GuideBlock); }

// static
GuideBlock* GuideBlock::create(QObject* parent, const QString& guideId,
                               const QJsonObject& blockObj) {
  Q_ASSERT(parent);

  GuideBlock* block = new GuideBlock(parent);

  QString blockId = blockObj["id"].toString();
  if (blockId.isEmpty()) {
    logger.error() << "Empty block ID for guide";
    return nullptr;
  }

  block->m_id = QString("guide.%1.block.%2").arg(guideId).arg(blockId);

  QString type = blockObj["type"].toString();
  if (type == "title") {
    block->m_type = GuideModel::GuideBlockTypeTitle;
  } else if (type == "text") {
    block->m_type = GuideModel::GuideBlockTypeText;
  } else if (type == "olist") {
    block->m_type = GuideModel::GuideBlockTypeOrderedList;
  } else if (type == "ulist") {
    block->m_type = GuideModel::GuideBlockTypeUnorderedList;
  } else {
    logger.error() << "Invalid type for block for guide";
    return nullptr;
  }

  if (block->m_type == GuideModel::GuideBlockTypeOrderedList ||
      block->m_type == GuideModel::GuideBlockTypeUnorderedList) {
    QJsonValue subBlockArray = blockObj["content"];
    if (!subBlockArray.isArray()) {
      logger.error() << "No content for block type list in guide";
      return nullptr;
    }

    for (QJsonValue subBlockValue : subBlockArray.toArray()) {
      if (!subBlockValue.isObject()) {
        logger.error()
            << "Expected JSON object for block content list in guide";
        return nullptr;
      }

      QJsonObject subBlockObj = subBlockValue.toObject();
      QString subBlockId = subBlockObj["id"].toString();
      if (subBlockId.isEmpty()) {
        logger.error() << "Empty sub block ID for guide";
        return nullptr;
      }

      subBlockId = QString("guide.%1.block.%2.%3")
                       .arg(guideId)
                       .arg(blockId)
                       .arg(subBlockId);
      block->m_subBlockIds.append(subBlockId);
    }
  }

  return block;
}
