/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "windowsdaemontunnel.h"
#include "commandlineparser.h"
#include "constants.h"
#include "leakdetector.h"
#include "logger.h"
#include "platforms/windows/windowscommons.h"
#include "platforms/windows/daemon/wireguardutilswindows.h"

#include <QCoreApplication>

#include <Windows.h>

namespace {
Logger logger(LOG_WINDOWS, "WindowsDaemonTunnel");
}  // namespace

WindowsDaemonTunnel::WindowsDaemonTunnel(QObject* parent)
    : Command(parent, "tunneldaemon", "Activate the windows tunnel service") {
  MVPN_COUNT_CTOR(WindowsDaemonTunnel);
}

WindowsDaemonTunnel::~WindowsDaemonTunnel() {
  MVPN_COUNT_DTOR(WindowsDaemonTunnel);
}

int WindowsDaemonTunnel::run(QStringList& tokens) {
  Q_ASSERT(!tokens.isEmpty());

  logger.debug() << "Tunnel daemon service is starting";

  QCoreApplication app(CommandLineParser::argc(), CommandLineParser::argv());

  QCoreApplication::setApplicationName("Mozilla VPN Tunnel");
  QCoreApplication::setApplicationVersion(Constants::versionString());

  if (tokens.length() != 2) {
    logger.error() << "Expected 1 parameter only: the config file.";
    return 1;
  }
  QString maybeConfig = tokens.at(1);

  if (!maybeConfig.startsWith("[Interface]")) {
    logger.error() << "parameter Does not seem to be a config";
    return 1;
  }
  // This process will be used by the wireguard tunnel. No need to call
  // FreeLibrary.
  HMODULE tunnelLib = LoadLibrary(TEXT("tunnel.dll"));
  if (!tunnelLib) {
    WindowsCommons::windowsLog("Failed to load tunnel.dll");
    return 1;
  }

  typedef bool WireGuardTunnelService(const ushort* settings,
                                      const ushort* name);

  WireGuardTunnelService* tunnelProc = (WireGuardTunnelService*)GetProcAddress(
      tunnelLib, "WireGuardTunnelService");
  if (!tunnelProc) {
    WindowsCommons::windowsLog("Failed to get WireGuardTunnelService function");
    return 1;
  }
  auto name = WireguardUtilsWindows::s_interfaceName();
  if (!tunnelProc(maybeConfig.utf16(), name.utf16())) {
    logger.error() << "Failed to activate the tunnel service";
    return 1;
  }

  return 0;
}

static Command::RegistrationProxy<WindowsDaemonTunnel>
    s_commandWindowsDaemonTunnel;
